@@ -396,7 +396,7 @@ class ABBAbase:
             centers = np.r_[ centers, center ]
             
         # self.centers = centers
-        # strings, self.hashmap = symbolsAssign(labels)
+        strings, hashmap = symbolsAssign(labels)
         parameters = Model(centers, centers, hashm)
         return strings, parameters
 
